SerializationConfig

Struct SerializationConfig 

pub struct SerializationConfig { /* private fields */ }
A configuration used to Serialize TFHE-rs objects. This configuration decides if the object will be versioned and holds the max byte size of the written data.

Implementations

Source

impl SerializationConfig

pub fn new(serialized_size_limit: u64) -> Self

Creates a new serialization config. The default configuration will serialize the object with versioning information for backward compatibility. serialized_size_limit is the size limit (in number of bytes) of the serialized object (including the header).

pub fn new_with_unlimited_size() -> Self

Creates a new serialization config without any size check.

pub fn disable_size_limit(self) -> Self

Disables the size limit for serialized objects

pub fn disable_versioning(self) -> Self

Disable the versioning of serialized objects

pub fn with_size_limit(self, size: u64) -> Self

Sets the size limit for this serialization config

pub fn serialized_size<T: Serialize + Versionize + Named>( &self, object: &T, ) -> Result<u64>

Returns the size the object would take if serialized using the current config

The size is returned as a u64 to handle the serialization of large buffers under 32b architectures.

pub fn serialize_into<T: Serialize + Versionize + Named>( self, object: &T, writer: impl Write, ) -> Result<()>

Serializes an object into a writer, based on the current config. The written bytes can be deserialized using DeserializationConfig::deserialize_from.